"use strict";
var __create = Object.create;
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __getProtoOf = Object.getPrototypeOf;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toESM = (mod, isNodeMode, target) => (target = mod != null ? __create(__getProtoOf(mod)) : {}, __copyProps(
  // If the importer is in node compatibility mode or this is not an ESM
  // file that has been converted to a CommonJS file using a Babel-
  // compatible transform (i.e. "__esModule" has not been set), then set
  // "default" to the CommonJS "module.exports" for node compatibility.
  isNodeMode || !mod || !mod.__esModule ? __defProp(target, "default", { value: mod, enumerable: true }) : target,
  mod
));
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/terminal.ts
var terminal_exports = {};
__export(terminal_exports, {
  CancelError: () => CancelError,
  CommandError: () => CommandError,
  SpinnerError: () => SpinnerError,
  ascii: () => ascii,
  cancel: () => cancel,
  executeCommand: () => executeCommand,
  intro: () => intro,
  list: () => list,
  maskTokens: () => maskTokens,
  note: () => note,
  outro: () => outro,
  spinner: () => spinner,
  table: () => table
});
module.exports = __toCommonJS(terminal_exports);

// src/terminal/ascii.ts
var import_yoctocolors = require("yoctocolors");
var ascii = () => console.log(
  (0, import_yoctocolors.magentaBright)(`
  _________       __    __  .__            _____  .__        __
 /   _____/ _____/  |__/  |_|  |   ____   /     \\ |__| _____/  |_
 \\_____  \\_/ __ \\   __\\   __\\  | _/ __ \\ /  \\ /  \\|  |/    \\   __\\
 /        \\  ___/|  |  |  | |  |_\\  ___//    Y    \\  |   |  \\  |
/_________/\\_____>__|  |__| |____/\\_____>____|____/__|___|__/__|
`)
);

// src/logging/mask-tokens.ts
var maskTokens = (output) => {
  return output.replace(/sm_(pat|aat|sat)_[0-9a-zA-Z]+/g, "***");
};

// src/terminal/cancel.ts
var import_yoctocolors2 = require("yoctocolors");
var CancelError = class extends Error {
};
var cancel = (msg) => {
  console.log("");
  console.log((0, import_yoctocolors2.inverse)((0, import_yoctocolors2.redBright)(maskTokens(msg))));
  console.log("");
  throw new CancelError(msg);
};

// src/terminal/execute-command.ts
var import_node_child_process = require("child_process");
var CommandError = class extends Error {
  /**
   * Constructs a new CommandError
   * @param message - The error message
   * @param code - The exit code of the command
   * @param output - The output of the command
   */
  constructor(message, code, output) {
    super(message);
    this.code = code;
    this.output = output;
  }
};
async function executeCommand(command, args, options) {
  const child = (0, import_node_child_process.spawn)(command, args, { env: { ...process.env, ...options?.env } });
  process.stdin.pipe(child.stdin);
  const output = [];
  return new Promise((resolve, reject) => {
    child.stdout.on("data", (data) => {
      const maskedData = maskTokens(data.toString());
      if (!options?.silent) {
        process.stdout.write(maskedData);
      }
      output.push(maskedData);
    });
    child.stderr.on("data", (data) => {
      const maskedData = maskTokens(data.toString());
      if (!options?.silent) {
        process.stderr.write(maskedData);
      }
      output.push(maskedData);
    });
    child.on(
      "error",
      (err) => reject(new CommandError(err.message, "code" in err && typeof err.code === "number" ? err.code : 1, output))
    );
    child.on("close", (code) => {
      if (code === 0 || code === null || code === 143) {
        process.stdin.unpipe(child.stdin);
        resolve(output);
        return;
      }
      reject(new CommandError(`Command "${command}" exited with code ${code}`, code, output));
    });
  });
}

// src/terminal/intro.ts
var import_yoctocolors3 = require("yoctocolors");
var intro = (msg) => {
  console.log("");
  console.log((0, import_yoctocolors3.magentaBright)(maskTokens(msg)));
  console.log("");
};

// src/terminal/note.ts
var import_yoctocolors4 = require("yoctocolors");
var note = (message, level = "info") => {
  const maskedMessage = maskTokens(message);
  console.log("");
  if (level === "warn") {
    console.warn((0, import_yoctocolors4.yellowBright)(maskedMessage));
    return;
  }
  console.log(maskedMessage);
};

// src/terminal/list.ts
function list(title, items) {
  const formatItems = (items2) => {
    return items2.map((item) => {
      if (Array.isArray(item)) {
        return item.map((subItem) => `    \u2022 ${subItem}`).join("\n");
      }
      return `  \u2022 ${item}`;
    }).join("\n");
  };
  return note(`${title}:

${formatItems(items)}`);
}

// src/terminal/outro.ts
var import_yoctocolors5 = require("yoctocolors");
var outro = (msg) => {
  console.log("");
  console.log((0, import_yoctocolors5.inverse)((0, import_yoctocolors5.greenBright)(maskTokens(msg))));
  console.log("");
};

// src/terminal/spinner.ts
var import_is_in_ci = __toESM(require("is-in-ci"), 1);
var import_yocto_spinner = __toESM(require("yocto-spinner"), 1);
var import_yoctocolors6 = require("yoctocolors");
var SpinnerError = class extends Error {
  constructor(message, originalError) {
    super(message);
    this.originalError = originalError;
    this.name = "SpinnerError";
  }
};
var spinner = async (options) => {
  const handleError = (error) => {
    const errorMessage = maskTokens(error.message);
    note((0, import_yoctocolors6.redBright)(`${errorMessage}

${error.stack}`));
    throw new SpinnerError(errorMessage, error);
  };
  if (import_is_in_ci.default) {
    try {
      return await options.task();
    } catch (err) {
      return handleError(err);
    }
  }
  const spinner2 = (0, import_yocto_spinner.default)({ stream: process.stdout }).start(options.startMessage);
  try {
    const result = await options.task(spinner2);
    spinner2.success(options.stopMessage);
    await new Promise((resolve) => process.nextTick(resolve));
    return result;
  } catch (err) {
    spinner2.error((0, import_yoctocolors6.redBright)(`${options.startMessage} --> Error!`));
    return handleError(err);
  }
};

// src/string.ts
function capitalizeFirstLetter(val) {
  return String(val).charAt(0).toUpperCase() + String(val).slice(1);
}
function camelCaseToWords(s) {
  const result = s.replace(/([a-z])([A-Z])/g, "$1 $2");
  const withSpaces = result.replace(/([A-Z])([a-z])/g, " $1$2");
  const capitalized = capitalizeFirstLetter(withSpaces);
  return capitalized.replace(/\s+/g, " ").trim();
}

// src/terminal/table.ts
var import_console_table_printer = require("console-table-printer");
var import_yoctocolors7 = require("yoctocolors");
function table(title, data) {
  note(title);
  if (!data || data.length === 0) {
    note("No data to display");
    return;
  }
  const columnKeys = Object.keys(data[0]);
  const table2 = new import_console_table_printer.Table({
    columns: columnKeys.map((key) => ({
      name: key,
      title: (0, import_yoctocolors7.whiteBright)(camelCaseToWords(key)),
      alignment: "left"
    }))
  });
  table2.addRows(data);
  table2.printTable();
}
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  CancelError,
  CommandError,
  SpinnerError,
  ascii,
  cancel,
  executeCommand,
  intro,
  list,
  maskTokens,
  note,
  outro,
  spinner,
  table
});
//# sourceMappingURL=terminal.cjs.map